==> Bio-MAGE-20020902.3.tar.gz: Bio-MAGE-20020902.3/MAGE/Array/ManufactureLIMSBiomaterial.pm <==
##############################
#
# Bio::MAGE::Array::ManufactureLIMSBiomaterial
#
##############################
# C O P Y R I G H T   N O T I C E
#  Copyright (c) 2001-2002 by:
#    * The MicroArray Gene Expression Database Society (MGED)
#    * Rosetta Inpharmatics
#
# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

package Bio::MAGE::Array::ManufactureLIMSBiomaterial;

use strict;
use Carp;
use Bio::MAGE::Base;
use Bio::MAGE::Association;
use Bio::MAGE::Array::ManufactureLIMS;


use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $__ASSOCIATIONS);

require Exporter;

@ISA = qw(Bio::MAGE::Base Bio::MAGE::Array::ManufactureLIMS Exporter);
$VERSION = q[$Id: ManufactureLIMSBiomaterial.pm,v 1.1 2002/12/10 06:25:47 jason_e_stewart Exp $];

# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.
@EXPORT_OK = qw();


=head1 Bio::MAGE::Array::ManufactureLIMSBiomaterial

=head2 SYNOPSIS

  use Bio::MAGE::Array::ManufactureLIMSBiomaterial;

    # creating an empty instance
  my $manufacturelimsbiomaterial = Bio::MAGE::Array::ManufactureLIMSBiomaterial->new();

    # creating an already populated instance
  my $manufacturelimsbiomaterial = Bio::MAGE::Array::ManufactureLIMSBiomaterial->new(bioMaterialPlateCol=>$bioMaterialPlateCol_value,
			bioMaterialPlateRow=>$bioMaterialPlateRow_value,
			bioMaterialPlateIdentifier=>$bioMaterialPlateIdentifier_value);

    # setting and retrieving object attributes
  my $bioMaterialPlateCol_val = $manufacturelimsbiomaterial->bioMaterialPlateCol();
  $manufacturelimsbiomaterial->bioMaterialPlateCol($value);

  my $bioMaterialPlateRow_val = $manufacturelimsbiomaterial->bioMaterialPlateRow();
  $manufacturelimsbiomaterial->bioMaterialPlateRow($value);

  my $bioMaterialPlateIdentifier_val = $manufacturelimsbiomaterial->bioMaterialPlateIdentifier();
  $manufacturelimsbiomaterial->bioMaterialPlateIdentifier($value);


=head2 DESCRIPTION

From the MAGE-OM documentation for the C<ManufactureLIMSBiomaterial> class:

Stores the location from which a biomaterial was obtained.



=cut


=head2 INHERITANCE


Bio::MAGE::Array::ManufactureLIMSBiomaterial has the following super classes

=over 


=item * Bio::MAGE::Array::ManufactureLIMS


=back


=head2 CLASS METHODS

The following methods can all be called without first having an
instance of the class via the Bio::MAGE::Array::ManufactureLIMSBiomaterial->methodname() syntax.


=item new()

=item new(%args)


The object constructor C<new()> accepts the following optional
named-value style arguments:

=over


=item * bioMaterialPlateCol

Sets the value of the bioMaterialPlateCol attribute (from C<Bio::MAGE::Array::ManufactureLIMSBiomaterial>).


=item * bioMaterialPlateRow

Sets the value of the bioMaterialPlateRow attribute (from C<Bio::MAGE::Array::ManufactureLIMSBiomaterial>).


=item * bioMaterialPlateIdentifier

Sets the value of the bioMaterialPlateIdentifier attribute (from C<Bio::MAGE::Array::ManufactureLIMSBiomaterial>).


=item * quality

Sets the value of the quality attribute (from C<Bio::MAGE::Array::ManufactureLIMS>).


=item * feature

Sets the value of the feature association (from C<Bio::MAGE::Array::ManufactureLIMS>).


=item * identifierLIMS

Sets the value of the identifierLIMS association (from C<Bio::MAGE::Array::ManufactureLIMS>).


=item * bioMaterial

Sets the value of the bioMaterial association (from C<Bio::MAGE::Array::ManufactureLIMS>).


=item * security

Sets the value of the security association (from C<Bio::MAGE::Describable>).


=item * auditTrail

Sets the value of the auditTrail association (from C<Bio::MAGE::Describable>).


=item * descriptions

Sets the value of the descriptions association (from C<Bio::MAGE::Describable>).


=item * propertySets

Sets the value of the propertySets association (from C<Bio::MAGE::Extendable>).


=back



=cut

#
# code for new() inherited from Base.pm
#

=item $obj->set_slots(%parameters)

=item $obj->set_slots(\@name_list, \@value_list)

The C<set_slots()> method is used to set a number of slots at the same
time. It has two different invocation methods. The first takes a named
parameter list, and the second takes two array references.

B<Return value>: none

B<Side effects>: will call C<croak()> if a slot_name is used that the class
does not define.

=cut

#
# code for set_slots() inherited from Base.pm
#

=item $obj->get_slots(@name_list)

The C<get_slots()> method is used to get the values of a number of
slots at the same time.

B<Return value>: a list of instance objects

B<Side effects>: none

=cut

#
# code for get_slots() inherited from Base.pm
#

=item $val = $obj->set_slot($name,$val)

The C<set_slot()> method sets the slot C<$name> to the value C<$val>

B<Return value>: the new value of the slot, i.e. C<$val>

B<Side effects>: none

=cut

#
# code for set_slot() inherited from Base.pm
#

=item $val = $obj->get_slot($name)

The C<get_slot()> method is used to get the values of a number of
slots at the same time.

B<Return value>: a single slot value, or undef if the slot has not been
initialized.

B<Side effects>: none

=cut

#
# code for get_slot() inherited from Base.pm
#

=item @names = $obj->get_slot_names()

The C<get_slot_names()> method is used to retrieve the name of all
slots defined for a given object.

B<Return value>: a single slot value, or undef if the slot has not been
initialized.

B<Side effects>: none

=cut

#
# code for get_slot_names() inherited from Base.pm
#



=item $name = class_name()

Returns the full class name for this class, Bio::MAGE::Array::ManufactureLIMSBiomaterial.

=cut

sub class_name {
  return q[Bio::MAGE::Array::ManufactureLIMSBiomaterial];
}

=item $package_name = package()

Returns the unresolved package name (i.e. no 'Bio::MAGE::') of the
package that contains class, Bio::MAGE::Array::ManufactureLIMSBiomaterial.

=cut

sub package {
  return q[Array];
}

=item @classes = subclasses()

returns the list of subclasses for this class.

=cut

sub subclasses {
  my @list = ();
  return @list;
}

=item @classes = superclasses()

returns the list of superclasses for this class.

=cut

sub superclasses {
  my @list = ('Bio::MAGE::Array::ManufactureLIMS');
  return @list;
}

=item @methods = attribute_methods()

returns the list of attribute accessor methods for this class.

=cut

sub attribute_methods {
  my $class = shift;
  my @list = ('bioMaterialPlateCol', 'bioMaterialPlateRow', 'bioMaterialPlateIdentifier');
  if ($class->superclasses()) {
    foreach ($class->superclasses()) {
      push(@list,$_->attribute_methods());
    }
  }
  return @list;
}

=item @methods = association_methods()

returns the list of association accessor methods for this class.

=cut

sub association_methods {
  my $class = shift;
  my @list = ();
  if ($class->superclasses()) {
    foreach ($class->superclasses()) {
      push(@list,$_->association_methods());
    }
  }
  return @list;
}

=item %assns = associations()

returns the association meta-information in a hash where the keys are
the association names and the values are C<Bio::MAGE::Association>
objects that provide the meta-information for the association.

=cut

sub associations {
  my $class = shift;
  my @list = ();
  # superclasses first
  if ($class->superclasses()) {
    foreach ($class->superclasses()) {
      push(@list,$_->associations());
    }
  }
  # then associations from this class
  if (defined $__ASSOCIATIONS) {
    push(@list,@{$__ASSOCIATIONS})
  }
  return @list;
}


=head2 ATTRIBUTES

Attributes are simple data types that belong to a single instance of a
class. In the Perl implementation of the MAGE-OM classes, the
interface to attributes is implemented using separate setter and
getter methods for each attribute.

Bio::MAGE::Array::ManufactureLIMSBiomaterial: has the following attribute accessor methods:

=over


=item bioMaterialPlateCol

From the MAGE-OM documentation for the C<bioMaterialPlateCol> attribute:

The plate column from which a biomaterial was obtained.  Specified by a number.



=over


=item $val = $manufacturelimsbiomaterial->setBioMaterialPlateCol($val)

The restricted setter method for the bioMaterialPlateCol attribute.

Input parameters: the value to which the bioMaterialPlateCol attribute will be set 

Return value: the current value of the bioMaterialPlateCol attribute 

Side effects: none

Exceptions: will call C<croak()> if no input parameters are specified, or
if too many input parameters are specified 

=cut

sub setBioMaterialPlateCol {
  my $self = shift;
  croak(__PACKAGE__ . "::setBioMaterialPlateCol: no arguments passed to setter")
    unless @_;
  croak(__PACKAGE__ . "::setBioMaterialPlateCol: too many arguments passed to setter")
    if @_ > 1;
  my $val = shift;
  
  return $self->{__BIOMATERIALPLATECOL} = $val;
}



=item $val = $manufacturelimsbiomaterial->getBioMaterialPlateCol()

The restricted getter method for the bioMaterialPlateCol attribute.

Input parameters: none

Return value: the current value of the bioMaterialPlateCol attribute 

Side effects: none

Exceptions: will call C<croak()> if any input parameters are specified

=cut

sub getBioMaterialPlateCol {
  my $self = shift;
  croak(__PACKAGE__ . "::getBioMaterialPlateCol: arguments passed to getter")
    if @_;
  return $self->{__BIOMATERIALPLATECOL};
}




=back


=item bioMaterialPlateRow

From the MAGE-OM documentation for the C<bioMaterialPlateRow> attribute:

The plate row from which a biomaterial was obtained.  Specified by a letter.



=over


=item $val = $manufacturelimsbiomaterial->setBioMaterialPlateRow($val)

The restricted setter method for the bioMaterialPlateRow attribute.

Input parameters: the value to which the bioMaterialPlateRow attribute will be set 

Return value: the current value of the bioMaterialPlateRow attribute 

Side effects: none

Exceptions: will call C<croak()> if no input parameters are specified, or
if too many input parameters are specified 

=cut

sub setBioMaterialPlateRow {
  my $self = shift;
  croak(__PACKAGE__ . "::setBioMaterialPlateRow: no arguments passed to setter")
    unless @_;
  croak(__PACKAGE__ . "::setBioMaterialPlateRow: too many arguments passed to setter")
    if @_ > 1;
  my $val = shift;
  
  return $self->{__BIOMATERIALPLATEROW} = $val;
}



=item $val = $manufacturelimsbiomaterial->getBioMaterialPlateRow()

The restricted getter method for the bioMaterialPlateRow attribute.

Input parameters: none

Return value: the current value of the bioMaterialPlateRow attribute 

Side effects: none

Exceptions: will call C<croak()> if any input parameters are specified

=cut

sub getBioMaterialPlateRow {
  my $self = shift;
  croak(__PACKAGE__ . "::getBioMaterialPlateRow: arguments passed to getter")
    if @_;
  return $self->{__BIOMATERIALPLATEROW};
}




=back


=item bioMaterialPlateIdentifier

From the MAGE-OM documentation for the C<bioMaterialPlateIdentifier> attribute:

The plate from which a biomaterial was obtained.



=over


=item $val = $manufacturelimsbiomaterial->setBioMaterialPlateIdentifier($val)

The restricted setter method for the bioMaterialPlateIdentifier attribute.

Input parameters: the value to which the bioMaterialPlateIdentifier attribute will be set 

Return value: the current value of the bioMaterialPlateIdentifier attribute 

Side effects: none

Exceptions: will call C<croak()> if no input parameters are specified, or
if too many input parameters are specified 

=cut

sub setBioMaterialPlateIdentifier {
  my $self = shift;
  croak(__PACKAGE__ . "::setBioMaterialPlateIdentifier: no arguments passed to setter")
    unless @_;
  croak(__PACKAGE__ . "::setBioMaterialPlateIdentifier: too many arguments passed to setter")
    if @_ > 1;
  my $val = shift;
  
  return $self->{__BIOMATERIALPLATEIDENTIFIER} = $val;
}



=item $val = $manufacturelimsbiomaterial->getBioMaterialPlateIdentifier()

The restricted getter method for the bioMaterialPlateIdentifier attribute.

Input parameters: none

Return value: the current value of the bioMaterialPlateIdentifier attribute 

Side effects: none

Exceptions: will call C<croak()> if any input parameters are specified

=cut

sub getBioMaterialPlateIdentifier {
  my $self = shift;
  croak(__PACKAGE__ . "::getBioMaterialPlateIdentifier: arguments passed to getter")
    if @_;
  return $self->{__BIOMATERIALPLATEIDENTIFIER};
}




=back

Attributes Inherited from Bio::MAGE::Array::ManufactureLIMS


=item quality

From the MAGE-OM documentation for the C<quality> attribute:

A brief description of the quality of the array manufacture process.



=over


=item $val = $manufacturelims->setQuality($val)

The restricted setter method for the quality attribute.

Input parameters: the value to which the quality attribute will be set 

Return value: the current value of the quality attribute 

Side effects: none

Exceptions: will call C<croak()> if no input parameters are specified, or
if too many input parameters are specified 

=cut


=item $val = $manufacturelims->getQuality()

The restricted getter method for the quality attribute.

Input parameters: none

Return value: the current value of the quality attribute 

Side effects: none

Exceptions: will call C<croak()> if any input parameters are specified

=cut



=back



=back


=cut



sub initialize {
  my $self = shift;
  return 1;
}



=head1 BUGS

Please send bug reports to mged-mage@lists.sf.net

=head1 AUTHOR

Jason E. Stewart (www.openinformatics.com)

=head1 SEE ALSO

perl(1).

=cut

#
# End the module by returning a true value
#
1;

==> Bio-MAGE-20020902.6.tar.gz: Bio-MAGE-20020902.6/MAGE/Array/ManufactureLIMSBiomaterial.pm <==
##############################
#
# Bio::MAGE::Array::ManufactureLIMSBiomaterial
#
##############################
# C O P Y R I G H T   N O T I C E
#  Copyright (c) 2001-2002 by:
#    * The MicroArray Gene Expression Database Society (MGED)
#    * Rosetta Inpharmatics
#
# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

package Bio::MAGE::Array::ManufactureLIMSBiomaterial;

use strict;
use Carp;
use Bio::MAGE::Base;
use Bio::MAGE::Association;
use Bio::MAGE::Array::ManufactureLIMS;


use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $__ASSOCIATIONS);

require Exporter;

@ISA = qw(Bio::MAGE::Base Bio::MAGE::Array::ManufactureLIMS Exporter);
$VERSION = 20020902.6;

# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.
@EXPORT_OK = qw();


=head1 Bio::MAGE::Array::ManufactureLIMSBiomaterial

=head2 SYNOPSIS

  use Bio::MAGE::Array::ManufactureLIMSBiomaterial;

    # creating an empty instance
  my $manufacturelimsbiomaterial = Bio::MAGE::Array::ManufactureLIMSBiomaterial->new();

    # creating an already populated instance
  my $manufacturelimsbiomaterial = Bio::MAGE::Array::ManufactureLIMSBiomaterial->new(bioMaterialPlateCol=>$bioMaterialPlateCol_value,
			bioMaterialPlateIdentifier=>$bioMaterialPlateIdentifier_value,
			bioMaterialPlateRow=>$bioMaterialPlateRow_value);

    # setting and retrieving object attributes
  my $bioMaterialPlateCol_val = $manufacturelimsbiomaterial->bioMaterialPlateCol();
  $manufacturelimsbiomaterial->bioMaterialPlateCol($value);

  my $bioMaterialPlateIdentifier_val = $manufacturelimsbiomaterial->bioMaterialPlateIdentifier();
  $manufacturelimsbiomaterial->bioMaterialPlateIdentifier($value);

  my $bioMaterialPlateRow_val = $manufacturelimsbiomaterial->bioMaterialPlateRow();
  $manufacturelimsbiomaterial->bioMaterialPlateRow($value);


=head2 DESCRIPTION

From the MAGE-OM documentation for the C<ManufactureLIMSBiomaterial> class:

Stores the location from which a biomaterial was obtained.



=cut


=head2 INHERITANCE


Bio::MAGE::Array::ManufactureLIMSBiomaterial has the following super classes

=over 


=item * Bio::MAGE::Array::ManufactureLIMS


=back


=head2 CLASS METHODS

The following methods can all be called without first having an
instance of the class via the Bio::MAGE::Array::ManufactureLIMSBiomaterial->methodname() syntax.


=item new()

=item new(%args)


The object constructor C<new()> accepts the following optional
named-value style arguments:

=over


=item * bioMaterialPlateCol

Sets the value of the bioMaterialPlateCol attribute (this attribute was inherited
from class C<Bio::MAGE::Array::ManufactureLIMSBiomaterial>).



=item * bioMaterialPlateIdentifier

Sets the value of the bioMaterialPlateIdentifier attribute (this attribute was inherited
from class C<Bio::MAGE::Array::ManufactureLIMSBiomaterial>).



=item * bioMaterialPlateRow

Sets the value of the bioMaterialPlateRow attribute (this attribute was inherited
from class C<Bio::MAGE::Array::ManufactureLIMSBiomaterial>).



=item * quality

Sets the value of the quality attribute (this attribute was inherited
from class C<Bio::MAGE::Array::ManufactureLIMS>).



=item * bioMaterial

Sets the value of the bioMaterial association (this association was inherited
from class C<Bio::MAGE::Array::ManufactureLIMS>).

The value will be of type C<BioMaterial>.


=item * feature

Sets the value of the feature association (this association was inherited
from class C<Bio::MAGE::Array::ManufactureLIMS>).

The value will be of type C<Feature>.


=item * identifierLIMS

Sets the value of the identifierLIMS association (this association was inherited
from class C<Bio::MAGE::Array::ManufactureLIMS>).

The value will be of type C<DatabaseEntry>.


=item * descriptions

Sets the value of the descriptions association (this association was inherited
from class C<Bio::MAGE::Describable>).

The value will be of type C<Description>.


=item * security

Sets the value of the security association (this association was inherited
from class C<Bio::MAGE::Describable>).

The value will be of type C<Security>.


=item * auditTrail

Sets the value of the auditTrail association (this association was inherited
from class C<Bio::MAGE::Describable>).

The value will be of type C<Audit>.


=item * propertySets

Sets the value of the propertySets association (this association was inherited
from class C<Bio::MAGE::Extendable>).

The value will be of type C<NameValueType>.


=back



=cut

#
# code for new() inherited from Base.pm
#

=item $obj->set_slots(%parameters)

=item $obj->set_slots(\@name_list, \@value_list)

The C<set_slots()> method is used to set a number of slots at the same
time. It has two different invocation methods. The first takes a named
parameter list, and the second takes two array references.

B<Return value>: none

B<Side effects>: will call C<croak()> if a slot_name is used that the class
does not define.

=cut

#
# code for set_slots() inherited from Base.pm
#

=item $obj->get_slots(@name_list)

The C<get_slots()> method is used to get the values of a number of
slots at the same time.

B<Return value>: a list of instance objects

B<Side effects>: none

=cut

#
# code for get_slots() inherited from Base.pm
#

=item $val = $obj->set_slot($name,$val)

The C<set_slot()> method sets the slot C<$name> to the value C<$val>

B<Return value>: the new value of the slot, i.e. C<$val>

B<Side effects>: none

=cut

#
# code for set_slot() inherited from Base.pm
#

=item $val = $obj->get_slot($name)

The C<get_slot()> method is used to get the values of a number of
slots at the same time.

B<Return value>: a single slot value, or undef if the slot has not been
initialized.

B<Side effects>: none

=cut

#
# code for get_slot() inherited from Base.pm
#

=item @names = $obj->get_slot_names()

The C<get_slot_names()> method is used to retrieve the name of all
slots defined for a given object.

B<Return value>: a single slot value, or undef if the slot has not been
initialized.

B<Side effects>: none

=cut

#
# code for get_slot_names() inherited from Base.pm
#



=item $name = class_name()

Returns the full class name for this class, Bio::MAGE::Array::ManufactureLIMSBiomaterial.

=cut

sub class_name {
  return q[Bio::MAGE::Array::ManufactureLIMSBiomaterial];
}

=item $package_name = package()

Returns the unresolved package name (i.e. no 'Bio::MAGE::') of the
package that contains class, Bio::MAGE::Array::ManufactureLIMSBiomaterial.

=cut

sub package {
  return q[Array];
}

=item @classes = subclasses()

returns the list of subclasses for this class.

=cut

sub subclasses {
  my @list = ();
  return @list;
}

=item @classes = superclasses()

returns the list of superclasses for this class.

=cut

sub superclasses {
  my @list = ('Bio::MAGE::Array::ManufactureLIMS');
  return @list;
}

=item @methods = attribute_methods()

returns the list of attribute accessor methods for this class.

=cut

sub attribute_methods {
  my $class = shift;
  my @list = ('bioMaterialPlateCol',
'bioMaterialPlateIdentifier',
'bioMaterialPlateRow');
  if ($class->superclasses()) {
    foreach ($class->superclasses()) {
      push(@list,$_->attribute_methods());
    }
  }
  return @list;
}

=item @methods = association_methods()

returns the list of association accessor methods for this class.

=cut

sub association_methods {
  my $class = shift;
  my @list = ();
  if ($class->superclasses()) {
    foreach ($class->superclasses()) {
      push(@list,$_->association_methods());
    }
  }
  return @list;
}

=item %assns = associations()

returns the association meta-information in a hash where the keys are
the association names and the values are C<Bio::MAGE::Association>
objects that provide the meta-information for the association.

=cut

sub associations {
  my $class = shift;
  my @list = ();
  # superclasses first
  if ($class->superclasses()) {
    foreach ($class->superclasses()) {
      push(@list,$_->associations());
    }
  }
  # then associations from this class
  if (defined $__ASSOCIATIONS) {
    push(@list,@{$__ASSOCIATIONS})
  }
  return @list;
}


=head2 ATTRIBUTES

Attributes are simple data types that belong to a single instance of a
class. In the Perl implementation of the MAGE-OM classes, the
interface to attributes is implemented using separate setter and
getter methods for each attribute.

Bio::MAGE::Array::ManufactureLIMSBiomaterial: has the following attribute accessor methods:

=over


=item bioMaterialPlateCol

From the MAGE-OM documentation for the C<bioMaterialPlateCol> attribute:

The plate column from which a biomaterial was obtained.  Specified by a number.



=over


=item $val = $manufacturelimsbiomaterial->setBioMaterialPlateCol($val)

The restricted setter method for the bioMaterialPlateCol attribute.

Input parameters: the value to which the bioMaterialPlateCol attribute will be set 

Return value: the current value of the bioMaterialPlateCol attribute 

Side effects: none

Exceptions: will call C<croak()> if no input parameters are specified, or
if too many input parameters are specified 

=cut

sub setBioMaterialPlateCol {
  my $self = shift;
  croak(__PACKAGE__ . "::setBioMaterialPlateCol: no arguments passed to setter")
    unless @_;
  croak(__PACKAGE__ . "::setBioMaterialPlateCol: too many arguments passed to setter")
    if @_ > 1;
  my $val = shift;
  
  return $self->{__BIOMATERIALPLATECOL} = $val;
}



=item $val = $manufacturelimsbiomaterial->getBioMaterialPlateCol()

The restricted getter method for the bioMaterialPlateCol attribute.

Input parameters: none

Return value: the current value of the bioMaterialPlateCol attribute 

Side effects: none

Exceptions: will call C<croak()> if any input parameters are specified

=cut

sub getBioMaterialPlateCol {
  my $self = shift;
  croak(__PACKAGE__ . "::getBioMaterialPlateCol: arguments passed to getter")
    if @_;
  return $self->{__BIOMATERIALPLATECOL};
}




=back


=item bioMaterialPlateIdentifier

From the MAGE-OM documentation for the C<bioMaterialPlateIdentifier> attribute:

The plate from which a biomaterial was obtained.



=over


=item $val = $manufacturelimsbiomaterial->setBioMaterialPlateIdentifier($val)

The restricted setter method for the bioMaterialPlateIdentifier attribute.

Input parameters: the value to which the bioMaterialPlateIdentifier attribute will be set 

Return value: the current value of the bioMaterialPlateIdentifier attribute 

Side effects: none

Exceptions: will call C<croak()> if no input parameters are specified, or
if too many input parameters are specified 

=cut

sub setBioMaterialPlateIdentifier {
  my $self = shift;
  croak(__PACKAGE__ . "::setBioMaterialPlateIdentifier: no arguments passed to setter")
    unless @_;
  croak(__PACKAGE__ . "::setBioMaterialPlateIdentifier: too many arguments passed to setter")
    if @_ > 1;
  my $val = shift;
  
  return $self->{__BIOMATERIALPLATEIDENTIFIER} = $val;
}



=item $val = $manufacturelimsbiomaterial->getBioMaterialPlateIdentifier()

The restricted getter method for the bioMaterialPlateIdentifier attribute.

Input parameters: none

Return value: the current value of the bioMaterialPlateIdentifier attribute 

Side effects: none

Exceptions: will call C<croak()> if any input parameters are specified

=cut

sub getBioMaterialPlateIdentifier {
  my $self = shift;
  croak(__PACKAGE__ . "::getBioMaterialPlateIdentifier: arguments passed to getter")
    if @_;
  return $self->{__BIOMATERIALPLATEIDENTIFIER};
}




=back


=item bioMaterialPlateRow

From the MAGE-OM documentation for the C<bioMaterialPlateRow> attribute:

The plate row from which a biomaterial was obtained.  Specified by a letter.



=over


=item $val = $manufacturelimsbiomaterial->setBioMaterialPlateRow($val)

The restricted setter method for the bioMaterialPlateRow attribute.

Input parameters: the value to which the bioMaterialPlateRow attribute will be set 

Return value: the current value of the bioMaterialPlateRow attribute 

Side effects: none

Exceptions: will call C<croak()> if no input parameters are specified, or
if too many input parameters are specified 

=cut

sub setBioMaterialPlateRow {
  my $self = shift;
  croak(__PACKAGE__ . "::setBioMaterialPlateRow: no arguments passed to setter")
    unless @_;
  croak(__PACKAGE__ . "::setBioMaterialPlateRow: too many arguments passed to setter")
    if @_ > 1;
  my $val = shift;
  
  return $self->{__BIOMATERIALPLATEROW} = $val;
}



=item $val = $manufacturelimsbiomaterial->getBioMaterialPlateRow()

The restricted getter method for the bioMaterialPlateRow attribute.

Input parameters: none

Return value: the current value of the bioMaterialPlateRow attribute 

Side effects: none

Exceptions: will call C<croak()> if any input parameters are specified

=cut

sub getBioMaterialPlateRow {
  my $self = shift;
  croak(__PACKAGE__ . "::getBioMaterialPlateRow: arguments passed to getter")
    if @_;
  return $self->{__BIOMATERIALPLATEROW};
}




=back

Attributes Inherited from Bio::MAGE::Array::ManufactureLIMS


=item quality

From the MAGE-OM documentation for the C<quality> attribute:

A brief description of the quality of the array manufacture process.



=over


=item $val = $manufacturelims->setQuality($val)

The restricted setter method for the quality attribute.

Input parameters: the value to which the quality attribute will be set 

Return value: the current value of the quality attribute 

Side effects: none

Exceptions: will call C<croak()> if no input parameters are specified, or
if too many input parameters are specified 

=cut


=item $val = $manufacturelims->getQuality()

The restricted getter method for the quality attribute.

Input parameters: none

Return value: the current value of the quality attribute 

Side effects: none

Exceptions: will call C<croak()> if any input parameters are specified

=cut



=back



=back


=cut



sub initialize {
  my $self = shift;
  return 1;
}



=head1 BUGS

Please send bug reports to mged-mage@lists.sf.net

=head1 AUTHOR

Jason E. Stewart (www.openinformatics.com)

=head1 SEE ALSO

perl(1).

=cut

#
# End the module by returning a true value
#
1;
